@@ -1,6 +1,6 @@
 package Module::Provision::Base;
 
-use namespace::sweep;
+use namespace::autoclean;
 
 use Moo;
 use Class::Usul::Constants;
@@ -282,7 +282,7 @@ sub __get_module_from { # Return main module name from contents of project file
    return
       (map    { s{ [-] }{::}gmx; $_ }
        map    { m{ \A [q\'\"] }mx ? eval $_ : $_ }
-       map    { m{ \A \s* (?:module_name|name) \s+ [=]?[>]? \s* ([^,;]+) [,;]? }imx }
+       map    { m{ \A \s* (?:module_name|module|name) \s+ [=]?[>]? \s* ([^,;]+) [,;]? }imx }
        grep   { m{ \A \s*   (module|name) }imx }
        split m{ [\n] }mx, $_[ 0 ])[ 0 ];
 }
