@@ -1,6 +1,6 @@
 package Module::Provision::Config;
 
-use namespace::sweep;
+use namespace::autoclean;
 
 use Moo;
 use Class::Usul::Constants;
@@ -36,6 +36,9 @@ has 'editor'           => is => 'lazy', isa => NonEmptySimpleStr,
 has 'home_page'        => is => 'lazy', isa => NonEmptySimpleStr,
    default             => 'http://example.com';
 
+has 'hooks'            => is => 'lazy', isa => ArrayRef[NonEmptySimpleStr],
+   default             => sub { [ 'commit-msg', 'pre-commit' ] };
+
 has 'license'          => is => 'lazy', isa => NonEmptySimpleStr,
    default             => 'perl';
 
@@ -130,6 +133,8 @@ Defines the following attributes;
 
 =item C<home_page>
 
+=item C<hooks>
+
 =item C<license>
 
 =item C<module_abstract>
